@@ -1,24 +1,24 @@
-import argparse
 import ast
+import json
+import os
 import sys
 
 import chardet
-import json
-import os
 import gitignore_parser
 
 
+import os
 import ast
-import os
-import argparse
 import chardet
+import argparse
 import gitignore_parser
 
+
 def describe_directory(directory, ignore_git=True):
     """
     Recursively describe all files in a directory.
     """
-    gitignore_path = os.path.abspath(os.path.join(directory, '.gitignore'))
+    gitignore_path = os.path.join(directory, '.gitignore')
     gitignore = gitignore_parser.parse_gitignore(gitignore_path) if ignore_git and os.path.isfile(
         gitignore_path) else None
     output = {}
@@ -30,14 +30,12 @@ def describe_directory(directory, ignore_git=True):
                     content = f.read()
                     encoding = chardet.detect(content)['encoding']
                 with open(path, encoding=encoding) as f:
-                    print(path)
                     code = f.read()
                     module = ast.parse(code)
                     module_data = {}
                     functions = {}
                     classes = {}
-                    parser = argparse.ArgumentParser(description='Describe Python directory')
-
+                    args = {}
                     for node in module.body:
                         if isinstance(node, ast.FunctionDef):
                             signature = ast.unparse(node.args)
@@ -61,27 +59,25 @@ def describe_directory(directory, ignore_git=True):
                                     else:
                                         docstring = ""
                                     methods.update({method.name.replace(" ", "") + "(" + signature.replace(" ",
-                                               "") + ")": docstring})
+                                                                                                           "") + ")": docstring})
+                                elif isinstance(method, ast.Assign):
+                                    if isinstance(method.value, ast.Call):
+                                        if isinstance(method.value.func, ast.Name) and method.value.func.id == 'argparse':
+                                            for arg in method.value.keywords:
+                                                args[arg.arg] = arg.value.s if isinstance(arg.value, ast.Str) else None
                             classes.update({node.name.replace(" ", ""): {"methods": methods}})
-
                     if functions:
                         module_data["functions"] = functions
                     if classes:
                         module_data["classes"] = classes
-                    if module_data:
+                    if args:
+                        module_data["args"] = args
+                    if module_data or code.strip() == "":
                         output[path.replace(" ", "")] = module_data
 
-                    # add argparse help text to module data
-                    parser.print_help()
-                    help_text = parser.format_help()
-                    module_data["argparse_help"] = _clean_output(help_text)
-
     return output
 
 
-
-
-
 def _clean_output(output):
     """
     Removes extra spaces, tabs, and newlines from argparse output.
@@ -92,8 +88,6 @@ def _clean_output(output):
     return output
 
 
-
-
 def main():
     """
     Parse command line arguments and describe directory.
